#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-FPKe973dysnInOUVaCLUdu
key:                  ghcide-2.3.0.0-FPKe973dysnInOUVaCLUdu
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  5623f38fee0d2a65be2e61c0b62f0123
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-FPKe973dysnInOUVaCLUdu
depends:
    Diff-0.5-KEZ9YIzWdyM3F5SFakDIw6 Glob-0.10.2-LQYbd0wNnOB58MUTK2wq9r
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU array-0.5.6.0
    async-2.2.6-L49doqolqOiLsPy3OvdI1h base-4.18.2.1
    base16-bytestring-1.0.2.0-B6baxbSLEYRHmpje8gg5IH binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-8beqaZQCG6YFLwD8uR7pTp
    co-log-core-0.3.2.6-39Wv1c0c3NEAmuSWUqUwqo containers-0.6.7
    cryptohash-sha1-0.11.101.0-5Jq7ZwhxLUb86wbW6pJAd7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-3gAkNvjrVmy3M73pf6MCP7
    dependent-sum-0.7.2.0-EAyOcQhSpuQ8ukUO3cyqz4 directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-Aa3tWUyrAaR4MHvN1BZjwo exceptions-0.10.7
    extra-1.7.16-EBdVSHGIn1MFifI9eiYLtn filepath-1.4.300.1
    fingertree-0.1.6.3-JZAMG7XazpN87D7oYiZFy7
    focus-1.0.3.2-GRKBeLReHOwL7I6P3Olq4Q ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-6tjGOyiF7MI2wFeklmQIHu
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-1r3jkftvkSkHQEK6iNY8SK
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy
    hie-bios-0.12.0-6U8OzEx7Xxd95jWIKLUa38
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-ZotJ964dbF5LFdeyMGTNG
    hls-graph-2.3.0.0-1gCW9OZ847s2g9dsPcBpND
    hls-plugin-api-2.3.0.0-D1GElmNt2iK2Wijr4TmkFu
    implicit-hie-0.1.4.0-KHc4WOCbbAe5s73cGoaweZ
    implicit-hie-cradle-0.5.0.1-GYyRSZEzq0UFDaQnYyJAR2
    lens-5.3.4-4VhpdbpDp0x9CLN9dxQmc7
    list-t-1.0.5.7-JSevOgOwHd1Cc3KmYfG1Ab
    lsp-2.2.0.0-BBA8C8ebAHoAYQmS8hf6TA
    lsp-types-2.0.2.0-54pPdwKIcCc5Qtt9boAlpX mtl-2.3.1
    opentelemetry-0.8.0-9OcmEusDY8yBh6FDdmq8gP
    optparse-applicative-0.18.1.0-7oEyKoVs7Vv7h3tuBTvFI7
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-3tqZuvkzaQgKArc0IOnBsn
    prettyprinter-ansi-terminal-1.1.4-4JTxmby746A8nB3dZScSYR
    random-1.2.1.3-5FoUrrA3875KkJXWnCWBBA
    regex-tdfa-1.3.2.5-DSpNPpF3mjD6KIMmBJHiEZ
    row-types-1.0.1.2-EpdWJYAHg7XKOZxhFScaQ6
    safe-exceptions-0.1.7.4-LZv8NFJplAmBopXPxrgiz2
    sorted-list-0.2.3.1-3rvBSBXtWHFG8aJa0F2Wom
    sqlite-simple-0.4.19.0-Ci6OAF5Vg6eI8Qk0xowBmP stm-2.5.1.0
    stm-containers-1.2.1.1-BPDfpq0EmmMH1erA8iMJrm
    syb-0.7.3-AsxB5kY1s6JBFiF2Kn9gZL text-2.0.2
    text-rope-0.3-3hVOhF4Ry2F5957kYxdbl6 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-Jl71xZxtWw8GvgwO5TEzPz
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

